@@ -8,4 +8,6 @@ from dbt.include import glue
 Plugin = AdapterPlugin(
     adapter=GlueAdapter,
     credentials=GlueCredentials,
-    include_path=glue.PACKAGE_PATH)
+    include_path=glue.PACKAGE_PATH,
+    dependencies = ["spark"],
+)
